@@ -9,9 +9,6 @@ from enum import Enum
 from os import environ
 import json
 from uuid import uuid4
-
-from pymongo.collection import Collection
-
 # client = httpx.Client(
 #     base_url=environ.get("CVE_SEARCH_API", "https://cve.circ.lu/api"),
 #     timeout=float(environ.get("CVE_SEARCH_TIMEOUT", 10.0)),
@@ -24,8 +21,8 @@ from pymongo.collection import Collection
 logger = logging.getLogger("schemas")
 
 
-def find(id: UUID4, col: Collection) -> Any:
-    return col.find_one({"_id": str(id)})
+# def find(id: UUID4, col: Collection) -> Any:
+#     return col.find_one({"_id": str(id)})
 
 
 class BaseSchema(BaseModel):
@@ -125,7 +122,7 @@ class Asset(BaseAsset, ID):
 class BaseService(BaseSchema):
     campaign_id: UUID4
     ip: Optional[IPvAnyAddress]
-    hostname: str = ""
+    hostname: str
     port: int = 0
     protocol: NetworkProtocol = NetworkProtocol.ICMP
     labels: list[str] = []
@@ -241,3 +238,25 @@ class CampaignModule(BaseSchema):
     """A user-specified module scoped to a single campaign"""
     name: str 
     campaign_id: UUID4
+
+
+class KafkaHeader(BaseModel):
+    module: str
+    campaign_id: UUID4 = b""
+    service_ids: list[UUID4] = []
+    asset_id: list[UUID4] = []
+
+    def form(self) -> list[tuple[(str, bytes)]]:
+        """Create headers suitable for Kafka messages"""
+        items = json.loads(self.json()).items()
+        headers = []
+        for k, v in items:
+            if isinstance(v, UUID4):
+                headers.append((k, str(v).encode('latin-1')))
+            elif isinstance(v, list):
+                headers.append((k, json.dumps(v).encode('latin-1')))
+            else:
+                assert type(v) == str
+                headers.append((k, v.encode('latin-1')))
+        
+        return headers
\ No newline at end of file
